<?php
/**
 * @package		Depot.Administrator
 * @subpackage	com_depot
 * @author		Thomas Kuschel <thomas@kuschel.at>
 * @copyright	(C) 2023 KW4NZ, <https://www.kuschel.at>
 * @license		GNU General Public License version 2 or later; see LICENSE.md
 * @since		0.9.7
 */

namespace KW4NZ\Component\Depot\Administrator\Model;

use Joomla\CMS\MVC\Model\ListModel;
// use Joomla\CMS\Table\Table;
use Joomla\Database\ParameterType;

\defined('_JEXEC') or die;

class PackagesModel extends ListModel
{
	public function __construct($config = [])
	{
		$config['filter_fields'] = [
			'id',
			'p.id',
			'name',
			'p.name',
			'alias',
			'p.alias',
			'state',
			'p.state',
			'published',
			'p.published',
			'mounting_style_id',
			'p.mounting_style_id',
			'mounting_style',
			'description',
			'p.description',
		];
		parent::__construct($config);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return  \Joomla\Database\DatabaseQuery
	 *
	 * @since   1.6
	 */
	protected function getListQuery()
	{
		$db = $this->getDatabase();
		$query = $db->getQuery(true);


		//		$query->select('*')
//			->from($db->quoteName('#__depot', 'd'));

		// order by
//		$query->order('d.id ASC');
//		if (true) {
//			return $query;
//		}

		// select the required fields from the table
		$query->select(
			$this->getState(
				'list.select',
				[
					$db->quoteName('p.id'),
					$db->quoteName('p.name'),
					$db->quoteName('p.alias'),
					$db->quoteName('p.description'),
					$db->quoteName('p.image'),
					$db->quoteName('p.state'),
				]
			)
		)
			->select(
				[
					$db->quoteName('u.name', 'creator'),
					$db->quoteName('ms.title', 'mounting_style'),
				]
			)
			->from($db->quoteName('#__depot_package', 'p'))
			->join('LEFT', $db->quoteName('#__users', 'u'), $db->quoteName('u.id') . ' = ' . $db->quoteName('p.checked_out'))
			->join('LEFT', $db->quoteName('#__depot_mounting_style', 'ms'), $db->quoteName('ms.id') . ' = ' . $db->quoteName('p.mounting_style_id'));

		// filter: like / search
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			$like = $db->quote('%' . $search . '%');
			$query->where($db->quoteName('p.name') . ' LIKE ' . $like);
		}

		// Filter by published state
		$published = (string) $this->getState('filter.published');
		if (is_numeric($published)) {
			$published = (int) $published;
			$query->where($db->quoteName('p.state') . ' = :published')
				->bind(':published', $published, ParameterType::INTEGER);
		} elseif ($published === '') {
			$query->where($db->quoteName('p.state') . ' IN (0, 1)');
		}

		// add list ordering clause
		$orderCol = $this->state->get('list.ordering', 'id');
		$orderDirn = $this->state->get('list.direction', 'asc');
		$query->order($db->escape($orderCol) . ' ' . $db->escape($orderDirn));

		return $query;
	}
}